==> okteta-0.25.5.tar.xz: okteta-0.25.5/libs/kasten/core/io/abstractconnectjob_p.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTCONNECTJOB_P_H
#define ABSTRACTCONNECTJOB_P_H

#include "abstractconnectjob.h"

namespace Kasten {

class AbstractConnectJobPrivate
{
public:
    explicit AbstractConnectJobPrivate(AbstractConnectJob* parent);

    virtual ~AbstractConnectJobPrivate();

protected:
    AbstractConnectJob* const q_ptr;
};

inline AbstractConnectJobPrivate::AbstractConnectJobPrivate(AbstractConnectJob* parent)
    : q_ptr(parent)
{}

inline AbstractConnectJobPrivate::~AbstractConnectJobPrivate() = default;

}

#endif

==> okteta_15.12.3.orig.tar.xz: okteta-15.12.3/libs/kasten/core/io/abstractconnectjob_p.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTCONNECTJOB_P_H
#define ABSTRACTCONNECTJOB_P_H

#include "abstractconnectjob.h"


namespace Kasten
{

class AbstractConnectJobPrivate
{
  public:
    explicit AbstractConnectJobPrivate( AbstractConnectJob* parent );

    virtual ~AbstractConnectJobPrivate();

  protected:
    AbstractConnectJob* const q_ptr;
};


inline AbstractConnectJobPrivate::AbstractConnectJobPrivate( AbstractConnectJob* parent )
  : q_ptr( parent )
{}

inline AbstractConnectJobPrivate::~AbstractConnectJobPrivate()
{}

}

#endif
